==> segatex-8.000.tar.gz: segatex-8.000/src/semanage_core_port_process.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qlayout.h>
#include <qpushbutton.h>
#include <qradiobutton.h>
#include <q3buttongroup.h>
#include <qlineedit.h>
#include <q3textedit.h>
//Added by qt3to4:
#include <Q3TextStream>
#include <Q3HBoxLayout>
#include <QLabel>
#include <Q3VBoxLayout>

#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <fstream>

#include "semanage_core_port_process.h"

#include <iostream>
using namespace std;

//default constructor
SemanageCorePortProcess::SemanageCorePortProcess(QWidget *parent, const char *name): QDialog(parent, name)
{
	setCaption(tr("Semanage Port Process"));
	textEdit1 = new Q3TextEdit(this);
	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));

	semanageEditLabel = new QLabel(tr("Add port(port_type):"), this );
	semanageEditLineEdit = new QLineEdit( this );
	semanageEditLineEdit->setText("");
	semanageEditLineEdit->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel2 = new QLabel(tr("protocol{tcp|udp}:"), this );
	semanageEditLineEdit2 = new QLineEdit( this );
	semanageEditLineEdit2->setText("");
	semanageEditLineEdit2->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel6 = new QLabel(tr("port_range:"), this );
	semanageEditLineEdit6 = new QLineEdit( this );
	semanageEditLineEdit6->setText("");
	semanageEditLineEdit6->setPaletteBackgroundColor(QColor(255,100,200));
	addButton = new QPushButton(tr("Add port"), this);
	addButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(addButton, SIGNAL(clicked()), this, SLOT(add_button_clicked()));

	semanageEditLabel3 = new QLabel(tr("Delete port(port_type):"), this );
	semanageEditLineEdit3 = new QLineEdit( this );
	semanageEditLineEdit3->setText("");
	semanageEditLineEdit3->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel7 = new QLabel(tr("protocol{tcp|udp}:"), this );
	semanageEditLineEdit7 = new QLineEdit( this );
	semanageEditLineEdit7->setText("");
	semanageEditLineEdit7->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel8 = new QLabel(tr("port_range:"), this );
	semanageEditLineEdit8 = new QLineEdit( this );
	semanageEditLineEdit8->setText("");
	semanageEditLineEdit8->setPaletteBackgroundColor(QColor(255,100,200));
	deleteButton = new QPushButton(tr("Delete port"), this);
	deleteButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(deleteButton, SIGNAL(clicked()), this, SLOT(delete_button_clicked()));

	semanageEditLabel4 = new QLabel(tr("Modify port(port_type):"), this );
	semanageEditLineEdit4 = new QLineEdit( this );
	semanageEditLineEdit4->setText("");
	semanageEditLineEdit4->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel5 = new QLabel(tr("protocol{tcp|udp}:"), this );
	semanageEditLineEdit5 = new QLineEdit( this );
	semanageEditLineEdit5->setText("");
	semanageEditLineEdit5->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel9 = new QLabel(tr("port_range:"), this );
	semanageEditLineEdit9 = new QLineEdit( this );
	semanageEditLineEdit9->setText("");
	semanageEditLineEdit9->setPaletteBackgroundColor(QColor(255,100,200));
	modifyButton = new QPushButton(tr("Modify port"), this);
	modifyButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(modifyButton, SIGNAL(clicked()), this, SLOT(modify_button_clicked()));

	closeButton = new QPushButton(tr("close"), this);
	//closing process button
	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
	closeButton->setDefault(true);

	//set textEdit smanage such and such -l
	semanage_core_base_port_process();

	mainLayout = new Q3VBoxLayout(this);
	mainLayout->setMargin(11);

	upperLayout = new Q3VBoxLayout;
	upperLayout->addWidget(textEdit1);

	middleLayout = new Q3VBoxLayout;
	leftLayout = new Q3HBoxLayout;
	rightLayout = new Q3HBoxLayout;
	thirdLayout = new Q3HBoxLayout;
	
	leftLayout->addWidget(semanageEditLabel);
	leftLayout->addWidget(semanageEditLineEdit);
	leftLayout->addWidget(semanageEditLabel2);
	leftLayout->addWidget(semanageEditLineEdit2);
	leftLayout->addWidget(semanageEditLabel6);
	leftLayout->addWidget(semanageEditLineEdit6);
	leftLayout->addWidget(addButton);
	rightLayout->addWidget(semanageEditLabel3);
	rightLayout->addWidget(semanageEditLineEdit3);
	rightLayout->addWidget(semanageEditLabel7);
	rightLayout->addWidget(semanageEditLineEdit7);
	rightLayout->addWidget(semanageEditLabel8);
	rightLayout->addWidget(semanageEditLineEdit8);
	rightLayout->addWidget(deleteButton);
	thirdLayout->addWidget(semanageEditLabel4);
	thirdLayout->addWidget(semanageEditLineEdit4);
	thirdLayout->addWidget(semanageEditLabel5);
	thirdLayout->addWidget(semanageEditLineEdit5);
	thirdLayout->addWidget(semanageEditLabel9);
	thirdLayout->addWidget(semanageEditLineEdit9);
	thirdLayout->addWidget(modifyButton);

	middleLayout->addLayout(leftLayout);
	middleLayout->addLayout(rightLayout);
	middleLayout->addLayout(thirdLayout);

	footLayout = new Q3HBoxLayout;
	footLayout->addStretch();
	footLayout->addWidget(closeButton);

	mainLayout->addLayout(upperLayout);
	mainLayout->addLayout(middleLayout);
	mainLayout->addLayout(footLayout);
	resize(1100,600);
}

/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCorePortProcess::add_button_clicked()
{
	semanageEditLineEdit_str = semanageEditLineEdit->text();
	semanageEditLineEdit2_str = semanageEditLineEdit2->text();
	semanageEditLineEdit6_str = semanageEditLineEdit6->text();
	add_button_clicked_process(semanageEditLineEdit_str,semanageEditLineEdit2_str,semanageEditLineEdit6_str);
}
/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCorePortProcess::delete_button_clicked()
{
	semanageEditLineEdit3_str = semanageEditLineEdit3->text();
	semanageEditLineEdit7_str = semanageEditLineEdit7->text();
	semanageEditLineEdit8_str = semanageEditLineEdit8->text();
	delete_button_clicked_process(semanageEditLineEdit3_str, semanageEditLineEdit7_str, semanageEditLineEdit8_str);
}
/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCorePortProcess::modify_button_clicked()
{
	semanageEditLineEdit4_str = semanageEditLineEdit4->text();
	semanageEditLineEdit5_str = semanageEditLineEdit5->text();
	semanageEditLineEdit9_str = semanageEditLineEdit9->text();
	modify_button_clicked_process(semanageEditLineEdit4_str,semanageEditLineEdit5_str,semanageEditLineEdit9_str);
}
/* this slot does just make .pp file */
void SemanageCorePortProcess::add_button_clicked_process(QString semanageEditLineEdit_str, QString semanageEditLineEdit2_str, QString semanageEditLineEdit6_str)
{
	semanageEditLineEdit_str_pp = "semanage port -a -t " + semanageEditLineEdit_str + " -p " + semanageEditLineEdit2_str + " " + semanageEditLineEdit6_str;
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/add_ported";
        ofstream os_add;
        os_add.open(make_module_file);
        if(os_add){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_add << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_add.close();
	//set textEdit semanage -l
	semanage_core_base_port_process();
	//outputfile_str_common2 = make_module_file;
}
/* this slot does just make .pp file */
void SemanageCorePortProcess::delete_button_clicked_process(QString semanageEditLineEdit3_str, QString semanageEditLineEdit7_str, QString semanageEditLineEdit8_str)
{
	semanageEditLineEdit_str_pp = "semanage port -d -t " + semanageEditLineEdit3_str + " -p " + semanageEditLineEdit7_str + " " + semanageEditLineEdit8_str;
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/delete_ported";
        ofstream os_delete;
        os_delete.open(make_module_file);
        if(os_delete){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_delete << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_delete.close();
	//set textEdit semanage -l
	semanage_core_base_port_process();
	//outputfile_str_common2 = make_module_file;
}
/* this slot does just make .pp file */
void SemanageCorePortProcess::modify_button_clicked_process(QString semanageEditLineEdit4_str, QString semanageEditLineEdit5_str, QString semanageEditLineEdit9_str)
{
	semanageEditLineEdit_str_pp = "semanage port -m -t " + semanageEditLineEdit4_str + " -p " + semanageEditLineEdit5_str + " " + semanageEditLineEdit9_str;
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/modify_ported";
        ofstream os_modify;
        os_modify.open(make_module_file);
        if(os_modify){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_modify << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_modify.close();
	//set textEdit semanage -l
	semanage_core_base_port_process();
}

// {boolean|login|user|port|interface|fcontext|translation}

void SemanageCorePortProcess::semanage_core_base_port_process()
{
        #define PWD_BUF 8600
        const char* semanage_port_list_file="/usr/share/segatex/semanage/1_port";
        ofstream os_test;
        os_test.open(semanage_port_list_file);
        if(os_test){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));

                read_fp = popen("export LANG=C;/usr/sbin/semanage port -l", "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_test << buffer;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
			}
			pclose(read_fp);
                }
        }
	os_test.close();
	//outputfile_str_common = "port_list";
	readFromOutputFile();
}

//this slot should be called from above slot
void SemanageCorePortProcess::readFromOutputFile()
{
	/////////////////////////////////////////////////////////////
	path = "/usr/share/segatex/semanage";
	/////////////////////////////////////////////////////////////
	forward_slash = "/";
	dir.setPath(path);
	dir_name = dir.absPath();
	/////////////////////////////////////////////////////////////
	dir.setFilter( QDir::Files );
        dir.setSorting( QDir::Name );
	files = dir.entryList("*port");
	/////////////////////////////////////////////////////////////
	it_d = files.begin();
	int order_x;
	order_x = 1;
	//first clear it all, unless double the file.
	textEdit1->clear();
		while(it_d != files.end()){
			name = *it_d;
			file_interface_name = dir_name + forward_slash + name;
			QFile file( file_interface_name );
			if ( file.open( QIODevice::ReadOnly ) ) {
				Q3TextStream stream( &file );
				////////////////////////////////////////////
				//int i,j,k,l,m,n;	
				if(order_x == 1)
					textEdit1->append("#########port list#########");
					textEdit1->append("");
				while ( !stream.atEnd() ) {
					line_analized = stream.readLine(); // line of text excluding '\n'
					textEdit1->append(line_analized);
				}
				textEdit1->setCursorPosition(0,0);
				order_x++;
				++it_d;
			}else{
				//do nothing
			}
			file.close();
		}
}

==> segatex-8.640.tar.gz: segatex-8.640/src/semanage_core_port_process.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <QLayout>
#include <QPushButton>
#include <QRadioButton>
#include <QButtonGroup>
#include <QLineEdit>
#include <QTextEdit>
#include <QTextStream>
#include <QLabel>

#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <fstream>

#include "semanage_core_port_process.h"

#include <iostream>
using namespace std;

//default constructor
SemanageCorePortProcess::SemanageCorePortProcess(QWidget *parent, const char *name): QDialog(parent, name)
{
	setCaption(tr("Semanage Port Process"));
	textEdit1 = new QTextEdit(this);
	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));

	semanageEditLabel = new QLabel(tr("Add port(port_type):"), this );
	semanageEditLineEdit = new QLineEdit( this );
	semanageEditLineEdit->setText("");
	semanageEditLineEdit->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel2 = new QLabel(tr("protocol{tcp|udp}:"), this );
	semanageEditLineEdit2 = new QLineEdit( this );
	semanageEditLineEdit2->setText("");
	semanageEditLineEdit2->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel6 = new QLabel(tr("port_range:"), this );
	semanageEditLineEdit6 = new QLineEdit( this );
	semanageEditLineEdit6->setText("");
	semanageEditLineEdit6->setPaletteBackgroundColor(QColor(255,100,200));
	addButton = new QPushButton(tr("Add port"), this);
	addButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(addButton, SIGNAL(clicked()), this, SLOT(add_button_clicked()));

	semanageEditLabel3 = new QLabel(tr("Delete port(port_type):"), this );
	semanageEditLineEdit3 = new QLineEdit( this );
	semanageEditLineEdit3->setText("");
	semanageEditLineEdit3->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel7 = new QLabel(tr("protocol{tcp|udp}:"), this );
	semanageEditLineEdit7 = new QLineEdit( this );
	semanageEditLineEdit7->setText("");
	semanageEditLineEdit7->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel8 = new QLabel(tr("port_range:"), this );
	semanageEditLineEdit8 = new QLineEdit( this );
	semanageEditLineEdit8->setText("");
	semanageEditLineEdit8->setPaletteBackgroundColor(QColor(255,100,200));
	deleteButton = new QPushButton(tr("Delete port"), this);
	deleteButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(deleteButton, SIGNAL(clicked()), this, SLOT(delete_button_clicked()));

	semanageEditLabel4 = new QLabel(tr("Modify port(port_type):"), this );
	semanageEditLineEdit4 = new QLineEdit( this );
	semanageEditLineEdit4->setText("");
	semanageEditLineEdit4->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel5 = new QLabel(tr("protocol{tcp|udp}:"), this );
	semanageEditLineEdit5 = new QLineEdit( this );
	semanageEditLineEdit5->setText("");
	semanageEditLineEdit5->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel9 = new QLabel(tr("port_range:"), this );
	semanageEditLineEdit9 = new QLineEdit( this );
	semanageEditLineEdit9->setText("");
	semanageEditLineEdit9->setPaletteBackgroundColor(QColor(255,100,200));
	modifyButton = new QPushButton(tr("Modify port"), this);
	modifyButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(modifyButton, SIGNAL(clicked()), this, SLOT(modify_button_clicked()));

	closeButton = new QPushButton(tr("close"), this);
	//closing process button
	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
	closeButton->setDefault(true);

	//set textEdit smanage such and such -l
	semanage_core_base_port_process();

	mainLayout = new QVBoxLayout(this);
	mainLayout->setMargin(11);

	upperLayout = new QVBoxLayout;
	upperLayout->addWidget(textEdit1);

	middleLayout = new QVBoxLayout;
	leftLayout = new QHBoxLayout;
	rightLayout = new QHBoxLayout;
	thirdLayout = new QHBoxLayout;
	
	leftLayout->addWidget(semanageEditLabel);
	leftLayout->addWidget(semanageEditLineEdit);
	leftLayout->addWidget(semanageEditLabel2);
	leftLayout->addWidget(semanageEditLineEdit2);
	leftLayout->addWidget(semanageEditLabel6);
	leftLayout->addWidget(semanageEditLineEdit6);
	leftLayout->addWidget(addButton);
	rightLayout->addWidget(semanageEditLabel3);
	rightLayout->addWidget(semanageEditLineEdit3);
	rightLayout->addWidget(semanageEditLabel7);
	rightLayout->addWidget(semanageEditLineEdit7);
	rightLayout->addWidget(semanageEditLabel8);
	rightLayout->addWidget(semanageEditLineEdit8);
	rightLayout->addWidget(deleteButton);
	thirdLayout->addWidget(semanageEditLabel4);
	thirdLayout->addWidget(semanageEditLineEdit4);
	thirdLayout->addWidget(semanageEditLabel5);
	thirdLayout->addWidget(semanageEditLineEdit5);
	thirdLayout->addWidget(semanageEditLabel9);
	thirdLayout->addWidget(semanageEditLineEdit9);
	thirdLayout->addWidget(modifyButton);

	middleLayout->addLayout(leftLayout);
	middleLayout->addLayout(rightLayout);
	middleLayout->addLayout(thirdLayout);

	footLayout = new QHBoxLayout;
	footLayout->addStretch();
	footLayout->addWidget(closeButton);

	mainLayout->addLayout(upperLayout);
	mainLayout->addLayout(middleLayout);
	mainLayout->addLayout(footLayout);
	resize(1100,600);
}

/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCorePortProcess::add_button_clicked()
{
	semanageEditLineEdit_str = semanageEditLineEdit->text();
	semanageEditLineEdit2_str = semanageEditLineEdit2->text();
	semanageEditLineEdit6_str = semanageEditLineEdit6->text();
	add_button_clicked_process(semanageEditLineEdit_str,semanageEditLineEdit2_str,semanageEditLineEdit6_str);
}
/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCorePortProcess::delete_button_clicked()
{
	semanageEditLineEdit3_str = semanageEditLineEdit3->text();
	semanageEditLineEdit7_str = semanageEditLineEdit7->text();
	semanageEditLineEdit8_str = semanageEditLineEdit8->text();
	delete_button_clicked_process(semanageEditLineEdit3_str, semanageEditLineEdit7_str, semanageEditLineEdit8_str);
}
/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCorePortProcess::modify_button_clicked()
{
	semanageEditLineEdit4_str = semanageEditLineEdit4->text();
	semanageEditLineEdit5_str = semanageEditLineEdit5->text();
	semanageEditLineEdit9_str = semanageEditLineEdit9->text();
	modify_button_clicked_process(semanageEditLineEdit4_str,semanageEditLineEdit5_str,semanageEditLineEdit9_str);
}
/* this slot does just make .pp file */
void SemanageCorePortProcess::add_button_clicked_process(QString semanageEditLineEdit_str, QString semanageEditLineEdit2_str, QString semanageEditLineEdit6_str)
{
	semanageEditLineEdit_str_pp = "semanage port -a -t " + semanageEditLineEdit_str + " -p " + semanageEditLineEdit2_str + " " + semanageEditLineEdit6_str;
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/add_ported";
        ofstream os_add;
        os_add.open(make_module_file);
        if(os_add){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_add << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_add.close();
	//set textEdit semanage -l
	semanage_core_base_port_process();
	//outputfile_str_common2 = make_module_file;
}
/* this slot does just make .pp file */
void SemanageCorePortProcess::delete_button_clicked_process(QString semanageEditLineEdit3_str, QString semanageEditLineEdit7_str, QString semanageEditLineEdit8_str)
{
	semanageEditLineEdit_str_pp = "semanage port -d -t " + semanageEditLineEdit3_str + " -p " + semanageEditLineEdit7_str + " " + semanageEditLineEdit8_str;
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/delete_ported";
        ofstream os_delete;
        os_delete.open(make_module_file);
        if(os_delete){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_delete << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_delete.close();
	//set textEdit semanage -l
	semanage_core_base_port_process();
	//outputfile_str_common2 = make_module_file;
}
/* this slot does just make .pp file */
void SemanageCorePortProcess::modify_button_clicked_process(QString semanageEditLineEdit4_str, QString semanageEditLineEdit5_str, QString semanageEditLineEdit9_str)
{
	semanageEditLineEdit_str_pp = "semanage port -m -t " + semanageEditLineEdit4_str + " -p " + semanageEditLineEdit5_str + " " + semanageEditLineEdit9_str;
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/modify_ported";
        ofstream os_modify;
        os_modify.open(make_module_file);
        if(os_modify){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_modify << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_modify.close();
	//set textEdit semanage -l
	semanage_core_base_port_process();
}

// {boolean|login|user|port|interface|fcontext|translation}

void SemanageCorePortProcess::semanage_core_base_port_process()
{
        #define PWD_BUF 8600
        const char* semanage_port_list_file="/usr/share/segatex/semanage/1_port";
        ofstream os_test;
        os_test.open(semanage_port_list_file);
        if(os_test){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));

                read_fp = popen("export LANG=C;/usr/sbin/semanage port -l", "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_test << buffer;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
			}
			pclose(read_fp);
                }
        }
	os_test.close();
	//outputfile_str_common = "port_list";
	readFromOutputFile();
}

//this slot should be called from above slot
void SemanageCorePortProcess::readFromOutputFile()
{
	/////////////////////////////////////////////////////////////
	path = "/usr/share/segatex/semanage";
	/////////////////////////////////////////////////////////////
	forward_slash = "/";
	dir.setPath(path);
	dir_name = dir.absPath();
	/////////////////////////////////////////////////////////////
	dir.setFilter( QDir::Files );
        dir.setSorting( QDir::Name );
	files = dir.entryList("*port");
	/////////////////////////////////////////////////////////////
	it_d = files.begin();
	int order_x;
	order_x = 1;
	//first clear it all, unless double the file.
	textEdit1->clear();
		while(it_d != files.end()){
			name = *it_d;
			file_interface_name = dir_name + forward_slash + name;
			QFile file( file_interface_name );
			if ( file.open( QIODevice::ReadOnly ) ) {
				QTextStream stream( &file );
				////////////////////////////////////////////
				//int i,j,k,l,m,n;	
				if(order_x == 1)
					textEdit1->append("#########port list#########");
					textEdit1->append("");
				while ( !stream.atEnd() ) {
					line_analized = stream.readLine(); // line of text excluding '\n'
					textEdit1->append(line_analized);
				}
				//textEdit1->setCursorPosition(0,0);
				order_x++;
				++it_d;
			}else{
				//do nothing
			}
			file.close();
		}
}
